@@ -1,6 +1,5 @@
 use crate::bindings::Windows::Win32::{
-    Graphics::Gdi::*, System::SystemServices::*, UI::DisplayDevices::*, UI::HiDpi::*,
-    UI::WindowsAndMessaging::*,
+    Foundation::*, Graphics::Gdi::*, UI::HiDpi::*, UI::WindowsAndMessaging::*,
 };
 use crate::geometry::*;
 use std::sync::Once;
@@ -15,7 +14,6 @@ pub fn get_dpi_from_point(pt: ScreenPosition) -> u32 {
             &mut dpi_x,
             &mut _dpi_y,
         )
-        .ok()
         .ok();
         dpi_x
     }
@@ -29,7 +27,7 @@ pub fn adjust_window_rect(size: PhysicalSize<u32>, style: u32, ex_style: u32, dp
             right: size.width as i32,
             bottom: size.height as i32,
         };
-        AdjustWindowRectExForDpi(&mut rc, style, FALSE, ex_style, dpi);
+        AdjustWindowRectExForDpi(&mut rc, style, false, ex_style, dpi);
         rc
     }
 }
@@ -38,11 +36,10 @@ pub fn enable_dpi_awareness() {
     static ENABLE_DPI_AWARENESS: Once = Once::new();
     unsafe {
         ENABLE_DPI_AWARENESS.call_once(|| {
-            if SetProcessDpiAwarenessContext(DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE_V2) != TRUE
-                && SetProcessDpiAwarenessContext(DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE) != TRUE
+            if !SetProcessDpiAwarenessContext(DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE_V2).as_bool()
+                && !SetProcessDpiAwarenessContext(DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE).as_bool()
             {
                 SetProcessDpiAwareness(PROCESS_PER_MONITOR_DPI_AWARE)
-                    .ok()
                     .ok();
             }
         });
@@ -51,6 +48,6 @@ pub fn enable_dpi_awareness() {
 
 pub fn enable_gui_thread() {
     unsafe {
-        IsGUIThread(TRUE);
+        IsGUIThread(true);
     }
 }
