@@ -1,7 +1,6 @@
 use crate::bindings::Windows::Win32::{
-    Globalization::*, Graphics::Gdi::*, System::SystemServices::*, UI::Controls::*,
-    UI::DisplayDevices::*, UI::HiDpi::*, UI::KeyboardAndMouseInput::*, UI::Shell::*,
-    UI::WindowsAndMessaging::*,
+    Foundation::*, Globalization::*, Graphics::Gdi::*, UI::Controls::WM_MOUSELEAVE, UI::HiDpi::*,
+    UI::KeyboardAndMouseInput::*, UI::Shell::*, UI::WindowsAndMessaging::*,
 };
 #[cfg(feature = "raw_input")]
 use crate::raw_input;
@@ -178,6 +177,8 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                         );
                     }
                 });
+                let wnd = handle.state.read().unwrap();
+                wnd.cursor.set();
                 LRESULT(0)
             }
             WM_MOUSELEAVE => {
@@ -543,7 +544,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     }
                     _ => {
                         return call_other::<T>(hwnd, msg, wparam, lparam);
-                    },
+                    }
                 }
                 LRESULT(0)
             }
